package puma.control;

import java.util.Vector;

/** Command, das Ausleihe markierter Objekte umsetzt.
 *  @author Sven Mller
 */
public class AusleiheCmd extends Command {
   
   /** Standard-Konstruktor.
    * @param serverApp  Ein Rckverweis auf die aufrufende Server-Instanz.
    */
   public AusleiheCmd(ServerApplication serverApp) {
      super(serverApp);
   }
      
   /** Fhrt die dem Command zugeordnete Aktion aus.
    *  
    * Es wird ein neues Objekt vom Typ I_StatusAendern erzeugt. Diesem werden im
    * Konstruktor ein Array von Inventarnummern (welches aus dem bergebenen
    * InType-Objekt <i>in</i> gewonnen wird), der neue Status "Ausgeliehen" und
    * der Benutzer (dessen Benutzernamen ber die Instanzvariable serverApp 
    * ermittelt wird) bergeben.<br>
    * Die Methode execute() des so erzeugten Objekts liefert einen Vector mit
    * Meldungen (Strings) mit, die von <i>out</i> in das Ausgabeformat konvertiert
    * werden. Tritt ein Fehler auf wird stattdessen auf die gleiche Weise
    * eine Fehlermeldung erzeugt.
    *
    * @see I_StatusAendern
    * @param in Objekt, das Input-Daten liefert.
    * @param out Objekt, das fr die Darstellung der Output-Daten sorgt.
    */
       
   public void execute(InType in, OutType out) {
      try {
         I_StatusAendern changeObj = 
            new I_StatusAendern(in.getInvNrArray(), 
               "AUSGELIEHEN", serverApp.getUserID() );
         out.setMessageArray( changeObj.execute() );
      } catch (Exception e) { out.createErrorMsg(e); }
   }   

}
