package puma.control;

import javax.servlet.http.HttpServletRequest;
import java.util.*;
import puma.database.*;

/** Diese Klasse kapselt einen HttpServletRequest mit dem Ziel dessen
 *  Parameter (die Benutzereingaben) fr andere Objekte in geeigneter 
 *  Formatierung zugreifbar zu machen.
 *  @author Sven Mller
 */
public class InputDataManager implements InType {
   /** Instanz, die im Konstruktor bergeben wird.
    */
   private HttpServletRequest request;
   
	/** Konstruktor erhlt Referenz auf den benoetigten HttpServletRequest
	 */
	public InputDataManager(HttpServletRequest request) {
	   this.request = request;
	}
		
			
	/** Signatur fuer Suche nach Instanzen ermitteln.
	 *  @return Einen String mit Beschreibung einer Publikations-Signatur.
	 *  @exception java.util.NoSuchElementException Falls der Parameter
	 *  Signatur nicht existiert bzw. leer ist.
	 */
	public String getSignatur() throws NoSuchElementException {	
	   try {
	      String signatur = request.getParameter("wahl");
	      if ((signatur == null) || (signatur.equals("")))
	         throw new NoSuchElementException();
	      return signatur;
	   } catch (Exception e) {
	      throw new NoSuchElementException("Keine Publikation ausgewhlt!"); 
	   }	
	}
	
	
	/** Publikations-Suchschlssel ermitteln. Die Daten werden in einem
	 *  Liste Objekt gekapselt.
	 *  @return Eine Liste-Instanz mit dem Suchschlssel.
         *  @exception java.util.NoSuchElementException Falls kein Suchschlssel existiert.	 
	 */
	public Liste getPublikation() throws NoSuchElementException {
	   try {
	      Liste satz = new Liste();	   
	      String param = null;

	      param = request.getParameter("Titel");
	      if ((param != null) && (!param.equals("")));
	         satz.Anfuegen(new StringDaten("TITEL",param) );

	      param = request.getParameter("Autor");
	      if ((param != null)  && (!param.equals("")));
	         satz.Anfuegen(new StringDaten("AUTOREN",param) );

	      param = request.getParameter("ISBN");
	      if ((param != null) && (!param.equals("")));
	         satz.Anfuegen(new StringDaten("ISBN",param) );

	      param = request.getParameter("Verlag");
	      if ((param != null) && (!param.equals("")));
	         satz.Anfuegen(new StringDaten("VERLAG",param) );

	      if (satz.Anzahl() == 0)
	         throw new NoSuchElementException();
	      
	      return satz;
	   } catch (Exception e) {
	      throw new NoSuchElementException("Keine Suchanfrage spezifiziert!"); 
	   }	       	          	      	   
	}
	
	
	/** Array von markierten Inventarnummern ermitteln.
	 *  @return Array von ints, die die Inventarnummern markierter Instanzen
	 *  reprsentieren (ggf. leer, falls nichts markiert).
	 *  @exception java.util.NoSuchElementException Falls keine markierte Instanz existiert.
	 */	
	public int[] getInvNrArray() throws NoSuchElementException {
	   try {
  	      String[] params = request.getParameterValues("invNr");
			if (params.length == 0)
			   throw new NoSuchElementException();
				
	      int[] result = new int[params.length];
	      for (int i=0; i < params.length; i++) {
	         result[i] = Integer.parseInt(params[i]);
	      }
			return result;
	   } catch (Exception e) {
	      throw new NoSuchElementException("Kein Objekt markiert!");
	   }
	}
	
		
   /** Benutzernamen fuer einen Ausleiher ermitteln.
    *  Dieser steht in einer aufklappbaren Liste zur Verfgung.
    *  @return Einen String mit dem Benutzernamen oder null, falls kein
    *  Benutzer selektiert wurde.
    *  @exception java.util.NoSuchElementException Falls der Parameter Ausleiher nicht existiert
    */
	public int getAusleiher() throws NoSuchElementException {
	   try {
		   String ausleiher = request.getParameter("User");
			if ((ausleiher == null) || (ausleiher.equals("")))
			   throw new NoSuchElementException();
	      return Operationen.getInstance().holePersonIDvon(ausleiher);
	   } catch (Exception e) {
	      throw new NoSuchElementException("Kein Benutzername selektiert"); 
	   }	
   }
}
