package puma.control.testing;

import test.framework.*;
import puma.control.*;
import puma.database.*;
import java.io.*;
import javax.servlet.HttpServletRequest;

/** JUnit-TestCase fr die Kontrollobjekte
 * @author Sven Mller
 */
public class ControlTest extends TestCase {
				
	protected FormButton fSuchenBtn;	
	protected FormButton fWeitergabeBtn;
	protected Writer writer;
	protected InputDataManager idm;
	protected HTMLCreator creator;
	
	private final String signatur = "12345";
	private Liste searchKey = new Liste();	
		
	private void formSearchKey() {
      searchKey.Anfuegen(new StringDaten("Titel","Datenbanksysteme") );
      searchKey.Anfuegen(new StringDaten("Autor","Kemper/Eickler") );
      searchKey.Anfuegen(new StringDaten("Verlag","Oldenburg") );		
   }
      
	private final String ausleiher = "dummy";
		
   /** Standard-Konstruktor
    *  @param name Name des TestCases
    */
   public ControlTest(String name) {
      super(name);
   }
   
   /** setUp()-Methode, um global benutzte Objekte zu initialisieren
    */
   protected void setUp() {
      try {
         fSuchenBtn = (FormButton)(Class.forName(
               "control.SuchenBtn").newInstance() );      
         fWeitergabeBtn = (FormButton)(Class.forName(
               "control.WeitergabeBtn").newInstance() );
      } catch (Exception e) {
          System.out.println(e+": Instantiation Error");
      }
                         
      writer = new CharArrayWriter();
      creator = new HTMLCreator(writer);
      // verwendet "knstlichen" request!
      idm = new InputDataManager(new HttpServletRequest() );      
      
      formSearchKey();
   }
	
	/** Testet dynamisches erzeugen von 3 Buttons	 
	 */
	public void dynamicButtonTest() {    
      assert(fSuchenBtn instanceof SuchenBtn);
      assert(fWeitergabeBtn instanceof WeitergabeBtn);        
	}
	
	/** Testet, ob die richtigen Commands ausgefhrt werden.	 
	 */
	public void commandTest() {
	   fSuchenBtn.storeCommand(null);
	   assert(fSuchenBtn.getCommand() instanceof B_SuchenCmd);
	   fWeitergabeBtn.storeCommand(null);
	   assert(fWeitergabeBtn.getCommand() instanceof WeitergabeCmd);
	}
	
	/** Test des InputDataManager: Werden die Parameter korrekt zurckgeliefert?
	 */
	public void inputDataTest() {
	   assertEquals(idm.getSignatur(),signatur);	      
	   assertEquals(idm.getAusleiher(),ausleiher);
	   assertEquals(idm.getPublikation(),searchKey );
	}
	

   /** Generieren einer TestSuite fr JUnit
    *  Alle vorhandenen Tests (dynamisch) hinzufgen.
    */
   public static Test suite() {
      TestSuite suite= new TestSuite();
      suite.addTest(new ControlTest("dynamicButtonTest")); 
      suite.addTest(new ControlTest("commandTest"));       
      suite.addTest(new ControlTest("inputDataTest"));
      return suite;
   }
	
	/** Eine main-Funktion, die Kommandozeilenversion des TestRunners startet.
	 *  @param args[] Kommandozeilen-Parameter - wird nicht benutzt!
	 */
	public static void main(String args[]) {
	   test.textui.TestRunner.run(suite());
	}
}
